======
Models
======

.. image:: ../_images/Models.png

.. automodule:: audit_tools.audit.models

.. autoclass:: Access
    :members:

.. autoclass:: Process
    :members:

.. autoclass:: ModelAction
    :members:
